@@ -44,7 +44,7 @@ Payload: client -> lua
 dkr_loc_name_to_id: dict[str, int] = {}
 dkr_itm_name_to_id: dict[str, int] = {}
 
-version_number: str = "v1.1.0"
+version_number: str = "v1.1.1"
 apworld_version: str = "DKR" + version_number
 patched_rom_filename: str = "Diddy-Kong-Racing-AP-" + version_number + ".z64"
 vanilla_rom_md5: str = "4f0e07f0eeac7e5d7ce3a75461888d03"
@@ -346,7 +346,7 @@ def get_slot_payload(ctx: DiddyKongRacingContext) -> str:
         "slot_wizpig_2_amulet_pieces": ctx.slot_data["wizpig_2_amulet_pieces"],
         "slot_wizpig_2_balloons": ctx.slot_data["wizpig_2_balloons"],
         "slot_randomize_character_on_map_change": ctx.slot_data["randomize_character_on_map_change"],
-        "slot_mirrored_tracks": ctx.slot_data["mirrored_tracks"],
+        "slot_track_versions": ctx.slot_data["track_versions"],
         "slot_music": ctx.slot_data["music"],
         "slot_power_up_balloon_type": ctx.slot_data["power_up_balloon_type"],
         "slot_skip_trophy_races": ctx.slot_data["skip_trophy_races"]
