@@ -12,7 +12,7 @@ from .Locations import ALL_LOCATION_TABLE
 from .Names import ItemName, LocationName, RegionName
 from .Options import DiddyKongRacingOptions, OPTION_GROUPS
 from .Regions import connect_regions, connect_track_regions, create_regions, reconnect_found_entrance
-from .Rules import set_door_unlock_rules, set_region_access_rules, set_rules
+from .Rules import set_door_unlock_rules, set_region_access_rules, set_race_2_location_rules, set_rules
 
 from BaseUtils import get_archipelago_json
 GAME_NAME, AUTHOR, AP_VERSION, VERSION = get_archipelago_json("diddy_kong_racing")
@@ -57,7 +57,7 @@ class DiddyKongRacingWorld(World):
     options: DiddyKongRacingOptions
     origin_region_name: str = RegionName.TIMBERS_ISLAND
     slot_data: dict[str, Any] = {}
-    mirrored_tracks: list[bool]
+    track_versions: list[bool]
     music: list[int] = list(range(20))
     entrance_order: list[int] = list(range(20))
     door_unlock_requirements: list[int] = [0] * len(vanilla_door_unlock_info_list)
@@ -90,7 +90,7 @@ class DiddyKongRacingWorld(World):
         set_rules(self)
 
     def generate_basic(self) -> None:
-        self.set_mirrored_tracks()
+        self.set_track_versions()
         self.set_music()
 
     def pre_fill(self) -> None:
@@ -136,7 +136,7 @@ class DiddyKongRacingWorld(World):
             "wizpig_2_amulet_pieces": self.options.wizpig_2_amulet_pieces.value,
             "wizpig_2_balloons": self.options.wizpig_2_balloons.value,
             "randomize_character_on_map_change": "true" if self.options.randomize_character_on_map_change else "false",
-            "mirrored_tracks": self.mirrored_tracks,
+            "track_versions": self.track_versions,
             "music": self.music,
             "power_up_balloon_type": self.options.power_up_balloon_type.value,
             "skip_trophy_races": "true" if self.options.skip_trophy_races else "false"
@@ -184,16 +184,16 @@ class DiddyKongRacingWorld(World):
     def is_ffl_unused(self) -> bool:
         return self.options.victory_condition.value == 0 and not self.options.open_worlds
 
-    def set_mirrored_tracks(self) -> None:
+    def set_track_versions(self) -> None:
         num_tracks = 20
-        if self.options.mirrored_tracks.value == 0:
-            self.mirrored_tracks = [False] * num_tracks
-        elif self.options.mirrored_tracks.value == 1:
-            self.mirrored_tracks = [True] * num_tracks
+        if self.options.track_version.value == 0:
+            self.track_versions = [False] * num_tracks
+        elif self.options.track_version.value == 1:
+            self.track_versions = [True] * num_tracks
         else:
-            self.mirrored_tracks = []
+            self.track_versions = []
             for _ in range(num_tracks):
-                self.mirrored_tracks.append(bool(self.random.getrandbits(1)))
+                self.track_versions.append(bool(self.random.getrandbits(1)))
 
     def set_music(self) -> None:
         if self.options.randomize_music.value:
@@ -207,6 +207,7 @@ class DiddyKongRacingWorld(World):
         place_door_unlock_items(self)
         set_region_access_rules(self)
         set_door_unlock_rules(self)
+        set_race_2_location_rules(self)
 
     # For Universal Tracker
     def reconnect_found_entrances(self, found_key: str, data_storage_value: Any) -> None:
